Deprecated API
Contents
-
Deprecated ClassesClassDescriptionSince 7.2.0. This implementation has been superseded. It is not necessary to parse Java code in order to tokenize it.Since 7.7.0. The rule was renamed
UnitTestAssertionsShouldIncludeMessageRuleSince 7.7.0. The rule was renamedUnitTestContainsTooManyAssertsRuleSince 7.7.0. The rule was renamedUnitTestShouldIncludeAssertRuleSince 7.17.0. This rule is replaced byVariableCanBeInlinedRule.
-
Deprecated FieldsFieldDescriptionSince 7.14.0. Use
JavaMetrics.NPATH_COMP, which is available on more nodes, and uses Long instead of BigInteger.Since 7.21.0. Should have been private. This property descriptor is not used anymore. UseAbstractPropertySource.getPropertyDescriptor(String)instead.Since 7.21.0. Should have been private. This property descriptor is not used anymore. UseAbstractPropertySource.getPropertyDescriptor(String)instead.Since 7.21.0. Should have never been public.Since 7.21.0. Should have never been public.Since 7.21.0. Should have been private. This property descriptor is not used anymore. UseAbstractPropertySource.getPropertyDescriptor(String)instead.Since 7.21.0. Should have never been public.
-
Deprecated MethodsMethodDescriptionSince 7.8.0. Use
ASTTypeDeclaration.getPermitsClause()orJClassSymbol.getPermittedSubtypes()Since 7.14.0. This method just returns `this` and isn't useful.Since 6.10.0. FieldDeclaration may declare several variables, so this is not exhaustive Iterate on the VariableIds insteadSince 7.1.0. UseASTLambdaExpression.getBlockBody()Since 7.1.0. UseASTLambdaExpression.getExpressionBody()Since 7.12.0. See super method. This override is needed due to covariant return type change.Since 7.3.0. This method was added here by mistake. Record patterns don't declare a pattern variable for the whole pattern, but rather for individual record components, which can be accessed viaASTRecordPattern.getComponentPatterns().Since 7.1.0. This method is not very useful because the expression might be complex and not have a real "name". In this case we return the expression pretty printed.Since 7.12.0. See super method. This override is needed due to covariant return type change.Since 7.2.0. This implementation has been superseded. It is not necessary to parse Java code in order to tokenize it.Since 7.21.0. When metrics are used for (rule) properties, then the conventional enum mapping (from SCREAMING_SNAKE_CASE to camelCase) will be used for the enum values. SeePropertyFactory.conventionalEnumListProperty(String, Class).Since 7.21.0. When metrics are used for (rule) properties, then the conventional enum mapping (from SCREAMING_SNAKE_CASE to camelCase) will be used for the enum values. SeePropertyFactory.conventionalEnumListProperty(String, Class).Since 7.21.0. When metrics are used for (rule) properties, then the conventional enum mapping (from SCREAMING_SNAKE_CASE to camelCase) will be used for the enum values. SeePropertyFactory.conventionalEnumListProperty(String, Class).Since 7.18.0. This method is not used anymore and shouldn't be implemented.Since 7.18.0. This method is not used anymore and shouldn't be implemented.Since 7.18.0. This method is not used anymore and shouldn't be implemented.Since 7.1.0. This method will be removed. Don't use it.Since 7.17.0. This method is an implementation detail and will be internalized.Since 7.21.0. Should have been private.Since 7.21.0. Should have been private.Since 7.21.0. Should have been private.Since 7.17.0. UseJClassSymbol.annotationAppliesToContext(ElementType, LanguageVersion)Since 7.12.0. There is no real use case for mutating the upper bound. Also, the bound could have been changed to really anything, which means it wasn't necessarily correct for two of those type vars to compare equals.Since 7.11.0. UseTypeOps.isContextDependent(JExecutableSymbol)instead which is more flexible.Since 7.2.0. UseTypeOps.isConvertible(JTypeMirror, JTypeMirror)orTypeOps.isConvertibleNoCapture(JTypeMirror, JTypeMirror)instead.