Class ASTArrayDimExpr

java.lang.Object
net.sourceforge.pmd.lang.ast.impl.AbstractNode<net.sourceforge.pmd.lang.java.ast.AbstractJavaNode,JavaNode>
net.sourceforge.pmd.lang.ast.impl.javacc.AbstractJjtreeNode<net.sourceforge.pmd.lang.java.ast.AbstractJavaNode,JavaNode>
net.sourceforge.pmd.lang.java.ast.ASTArrayTypeDim
net.sourceforge.pmd.lang.java.ast.ASTArrayDimExpr
All Implemented Interfaces:
GenericNode<JavaNode>, JjtreeNode<JavaNode>, Node, TextAvailableNode, Annotatable, JavaNode, Reportable

public final class ASTArrayDimExpr extends ASTArrayTypeDim
Represents an array dimension initialized with an expression in an array allocation expression. This is always a child of ArrayDimensions. TODO not sure we need a separate node type here?

 ArrayDimExpr ::= TypeAnnotation* "[" Expression "]"