Class ASTMethodDeclaration

java.lang.Object
net.sourceforge.pmd.lang.ast.impl.AbstractNode<net.sourceforge.pmd.lang.java.ast.AbstractJavaNode,JavaNode>
net.sourceforge.pmd.lang.ast.impl.javacc.AbstractJjtreeNode<net.sourceforge.pmd.lang.java.ast.AbstractJavaNode,JavaNode>
net.sourceforge.pmd.lang.java.ast.ASTMethodDeclaration
All Implemented Interfaces:
GenericNode<JavaNode>, JjtreeNode<JavaNode>, Node, TextAvailableNode, Annotatable, ASTBodyDeclaration, ASTExecutableDeclaration, JavadocCommentOwner, JavaNode, ModifierOwner, ReturnScopeNode, SymbolDeclaratorNode, TypeParamOwnerNode, Reportable

public final class ASTMethodDeclaration extends AbstractJjtreeNode<net.sourceforge.pmd.lang.java.ast.AbstractJavaNode,JavaNode>
A method declaration, in a class or interface declaration. Since 7.0, this also represents annotation methods. Annotation methods have a much more restricted grammar though, in particular: They can however declare a default value.

 MethodDeclaration ::= ModifierList
                       TypeParameters?
                       Type
                       <IDENTIFIER>
                       FormalParameters
                       ArrayDimensions?
                       ThrowsList?
                       (Block | ";" )