Class SyntacticJavaTokenizerFactory

java.lang.Object
net.sourceforge.pmd.lang.java.ast.SyntacticJavaTokenizerFactory

@Deprecated public final class SyntacticJavaTokenizerFactory extends Object
Deprecated.
Since 7.2.0. This implementation has been superseded. It is not necessary to parse Java code in order to tokenize it.
Creates a tokenizer, that uses the syntactic grammar to provide context for the tokenizer when reducing the input characters to tokens.
  • Method Details

    • createTokenizer

      @Deprecated public static TokenManager<JavaccToken> createTokenizer(CharStream cs)
      Deprecated.
      Since 7.2.0. This implementation has been superseded. It is not necessary to parse Java code in order to tokenize it.